pub enum Rseed {
BeforeZip212(Fr),
AfterZip212([u8; 32]),
}Expand description
Enum for note randomness before and after ZIP 212.
Before ZIP 212, the note commitment trapdoor rcm must be a scalar value.
After ZIP 212, the note randomness rseed is a 32-byte sequence, used to derive
both the note commitment trapdoor rcm and the ephemeral private key esk.
Variants